---
name: Feature request
about: Suggest an idea for pyglet
title: ''
labels: enhancement
assignees: ''

---

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]


**Describe the solution you'd like**
A description of what you would like **pyglet** to do (or to do differently). 


**Additional context**
Add any other context or screenshots about the feature request here.
